/* A Bison parser, made from /home/RobertC/src/cygwin/setup/iniparse.y, by GNU bison 1.75.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

/* Written by Richard Stallman by simplifying the original so called
   ``semantic'' parser.  */

/* All symbols defined below should begin with yy or YY, to avoid
   infringing on user name space.  This should be done even for local
   variables, as they might otherwise be expanded by user macros.
   There are some unavoidable exceptions within include files to
   define necessary library symbols; they are noted "INFRINGES ON
   USER NAME SPACE" below.  */

/* Identify Bison output.  */
#define YYBISON	1

/* Pure parsers.  */
#define YYPURE	0

/* Using locations.  */
#define YYLSP_NEEDED 0



/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     STRING = 258,
     SETUP_TIMESTAMP = 259,
     SETUP_VERSION = 260,
     PACKAGEVERSION = 261,
     INSTALL = 262,
     SOURCE = 263,
     SDESC = 264,
     LDESC = 265,
     CATEGORY = 266,
     DEPENDS = 267,
     REQUIRES = 268,
     APATH = 269,
     PPATH = 270,
     INCLUDE_SETUP = 271,
     EXCLUDE_PACKAGE = 272,
     DOWNLOAD_URL = 273,
     T_PREV = 274,
     T_CURR = 275,
     T_TEST = 276,
     MD5 = 277,
     INSTALLEDSIZE = 278,
     MAINTAINER = 279,
     PRIORITY = 280,
     DESCTAG = 281,
     DESCRIPTION = 282,
     FILESIZE = 283,
     ARCHITECTURE = 284,
     SOURCEPACKAGE = 285,
     MD5LINE = 286,
     RECOMMENDS = 287,
     PREDEPENDS = 288,
     SUGGESTS = 289,
     CONFLICTS = 290,
     REPLACES = 291,
     PROVIDES = 292,
     PACKAGENAME = 293,
     STRTOEOL = 294,
     PARAGRAPH = 295,
     EMAIL = 296,
     COMMA = 297,
     OR = 298,
     NL = 299,
     AT = 300,
     OPENBRACE = 301,
     CLOSEBRACE = 302,
     EQUAL = 303,
     GT = 304,
     LT = 305,
     GTEQUAL = 306,
     LTEQUAL = 307,
     OPENSQUARE = 308,
     CLOSESQUARE = 309,
     BINARYPACKAGE = 310,
     BUILDDEPENDS = 311,
     STANDARDSVERSION = 312,
     FORMAT = 313,
     DIRECTORY = 314,
     FILES = 315
   };
#endif
#define STRING 258
#define SETUP_TIMESTAMP 259
#define SETUP_VERSION 260
#define PACKAGEVERSION 261
#define INSTALL 262
#define SOURCE 263
#define SDESC 264
#define LDESC 265
#define CATEGORY 266
#define DEPENDS 267
#define REQUIRES 268
#define APATH 269
#define PPATH 270
#define INCLUDE_SETUP 271
#define EXCLUDE_PACKAGE 272
#define DOWNLOAD_URL 273
#define T_PREV 274
#define T_CURR 275
#define T_TEST 276
#define MD5 277
#define INSTALLEDSIZE 278
#define MAINTAINER 279
#define PRIORITY 280
#define DESCTAG 281
#define DESCRIPTION 282
#define FILESIZE 283
#define ARCHITECTURE 284
#define SOURCEPACKAGE 285
#define MD5LINE 286
#define RECOMMENDS 287
#define PREDEPENDS 288
#define SUGGESTS 289
#define CONFLICTS 290
#define REPLACES 291
#define PROVIDES 292
#define PACKAGENAME 293
#define STRTOEOL 294
#define PARAGRAPH 295
#define EMAIL 296
#define COMMA 297
#define OR 298
#define NL 299
#define AT 300
#define OPENBRACE 301
#define CLOSEBRACE 302
#define EQUAL 303
#define GT 304
#define LT 305
#define GTEQUAL 306
#define LTEQUAL 307
#define OPENSQUARE 308
#define CLOSESQUARE 309
#define BINARYPACKAGE 310
#define BUILDDEPENDS 311
#define STANDARDSVERSION 312
#define FORMAT 313
#define DIRECTORY 314
#define FILES 315




/* Copy the first part of user declarations.  */
#line 1 "/home/RobertC/src/cygwin/setup/iniparse.y"

/*
 * Copyright (c) 2000, Red Hat, Inc.
 *
 *     This program is free software; you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation; either version 2 of the License, or
 *     (at your option) any later version.
 *
 *     A copy of the GNU General Public License can be found at
 *     http://www.gnu.org/
 *
 * Written by DJ Delorie <dj@cygnus.com>
 *
 */

/* Parse the setup.ini files.  inilex.l provides the tokens for this. */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include "win32.h"
#include "ini.h"
#include "iniparse.h"
#include "PackageTrust.h"

extern int yyerror (String  const &s);
int yylex ();

#include "port.h"

#include "IniDBBuilder.h"

#define YYERROR_VERBOSE 1
#define YYINITDEPTH 1000
/*#define YYDEBUG 1*/

IniDBBuilder *iniBuilder;
extern int yylineno;

void add_correct_version();


/* Enabling traces.  */
#ifndef YYDEBUG
# define YYDEBUG 0
#endif

/* Enabling verbose error messages.  */
#ifdef YYERROR_VERBOSE
# undef YYERROR_VERBOSE
# define YYERROR_VERBOSE 1
#else
# define YYERROR_VERBOSE 0
#endif

#ifndef YYSTYPE
typedef int yystype;
# define YYSTYPE yystype
# define YYSTYPE_IS_TRIVIAL 1
#endif

#ifndef YYLTYPE
typedef struct yyltype
{
  int first_line;
  int first_column;
  int last_line;
  int last_column;
} yyltype;
# define YYLTYPE yyltype
# define YYLTYPE_IS_TRIVIAL 1
#endif

/* Copy the second part of user declarations.  */


/* Line 213 of /usr/share/bison/yacc.c.  */
#line 257 "iniparse.cc"

#if ! defined (yyoverflow) || YYERROR_VERBOSE

/* The parser invokes alloca or malloc; define the necessary symbols.  */

# if YYSTACK_USE_ALLOCA
#  define YYSTACK_ALLOC alloca
# else
#  ifndef YYSTACK_USE_ALLOCA
#   if defined (alloca) || defined (_ALLOCA_H)
#    define YYSTACK_ALLOC alloca
#   else
#    ifdef __GNUC__
#     define YYSTACK_ALLOC __builtin_alloca
#    endif
#   endif
#  endif
# endif

# ifdef YYSTACK_ALLOC
   /* Pacify GCC's `empty if-body' warning. */
#  define YYSTACK_FREE(Ptr) do { /* empty */; } while (0)
# else
#  if defined (__STDC__) || defined (__cplusplus)
#   include <stdlib.h> /* INFRINGES ON USER NAME SPACE */
#   define YYSIZE_T size_t
#  endif
#  define YYSTACK_ALLOC malloc
#  define YYSTACK_FREE free
# endif
#endif /* ! defined (yyoverflow) || YYERROR_VERBOSE */


#if (! defined (yyoverflow) \
     && (! defined (__cplusplus) \
	 || (YYLTYPE_IS_TRIVIAL && YYSTYPE_IS_TRIVIAL)))

/* A type that is properly aligned for any stack member.  */
union yyalloc
{
  short yyss;
  YYSTYPE yyvs;
  };

/* The size of the maximum gap between one aligned stack and the next.  */
# define YYSTACK_GAP_MAX (sizeof (union yyalloc) - 1)

/* The size of an array large to enough to hold all stacks, each with
   N elements.  */
# define YYSTACK_BYTES(N) \
     ((N) * (sizeof (short) + sizeof (YYSTYPE))				\
      + YYSTACK_GAP_MAX)

/* Copy COUNT objects from FROM to TO.  The source and destination do
   not overlap.  */
# ifndef YYCOPY
#  if 1 < __GNUC__
#   define YYCOPY(To, From, Count) \
      __builtin_memcpy (To, From, (Count) * sizeof (*(From)))
#  else
#   define YYCOPY(To, From, Count)		\
      do					\
	{					\
	  register YYSIZE_T yyi;		\
	  for (yyi = 0; yyi < (Count); yyi++)	\
	    (To)[yyi] = (From)[yyi];	\
	}					\
      while (0)
#  endif
# endif

/* Relocate STACK from its old location to the new one.  The
   local variables YYSIZE and YYSTACKSIZE give the old and new number of
   elements in the stack, and YYPTR gives the new location of the
   stack.  Advance YYPTR to a properly aligned location for the next
   stack.  */
# define YYSTACK_RELOCATE(Stack)					\
    do									\
      {									\
	YYSIZE_T yynewbytes;						\
	YYCOPY (&yyptr->Stack, Stack, yysize);				\
	Stack = &yyptr->Stack;						\
	yynewbytes = yystacksize * sizeof (*Stack) + YYSTACK_GAP_MAX;	\
	yyptr += yynewbytes / sizeof (*yyptr);				\
      }									\
    while (0)

#endif

#if defined (__STDC__) || defined (__cplusplus)
   typedef signed char yysigned_char;
#else
   typedef short yysigned_char;
#endif

/* YYFINAL -- State number of the termination state. */
#define YYFINAL  3
#define YYLAST   162

/* YYNTOKENS -- Number of terminals. */
#define YYNTOKENS  61
/* YYNNTS -- Number of nonterminals. */
#define YYNNTS  52
/* YYNRULES -- Number of rules. */
#define YYNRULES  112
/* YYNRULES -- Number of states. */
#define YYNSTATES  191

/* YYTRANSLATE(YYLEX) -- Bison symbol number corresponding to YYLEX.  */
#define YYUNDEFTOK  2
#define YYMAXUTOK   315

#define YYTRANSLATE(X) \
  ((unsigned)(X) <= YYMAXUTOK ? yytranslate[X] : YYUNDEFTOK)

/* YYTRANSLATE[YYLEX] -- Bison symbol number corresponding to YYLEX.  */
static const unsigned char yytranslate[] =
{
       0,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     1,     2,     3,     4,
       5,     6,     7,     8,     9,    10,    11,    12,    13,    14,
      15,    16,    17,    18,    19,    20,    21,    22,    23,    24,
      25,    26,    27,    28,    29,    30,    31,    32,    33,    34,
      35,    36,    37,    38,    39,    40,    41,    42,    43,    44,
      45,    46,    47,    48,    49,    50,    51,    52,    53,    54,
      55,    56,    57,    58,    59,    60
};

#if YYDEBUG
/* YYPRHS[YYN] -- Index of the first RHS symbol of rule number YYN in
   YYRHS.  */
static const unsigned short yyprhs[] =
{
       0,     0,     3,     7,     8,    11,    12,    17,    18,    23,
      24,    28,    29,    32,    36,    39,    42,    43,    46,    50,
      54,    58,    61,    64,    67,    71,    75,    79,    83,    87,
      91,    95,    99,   103,   107,   111,   112,   118,   124,   125,
     130,   131,   136,   137,   142,   143,   148,   149,   154,   155,
     160,   161,   166,   167,   172,   173,   178,   179,   184,   188,
     191,   193,   194,   197,   198,   201,   202,   205,   206,   208,
     209,   211,   212,   216,   217,   221,   222,   226,   230,   231,
     236,   237,   240,   242,   246,   247,   250,   251,   256,   257,
     260,   261,   265,   266,   268,   271,   272,   277,   278,   285,
     286,   291,   293,   295,   297,   299,   301,   302,   306,   307,
     310,   311,   312
};

/* YYRHS -- A `-1'-separated list of the rules' RHS. */
static const yysigned_char yyrhs[] =
{
      62,     0,    -1,    63,    68,    67,    -1,    -1,    63,    64,
      -1,    -1,     4,     3,    65,    44,    -1,    -1,     5,     3,
      66,    44,    -1,    -1,    67,    69,    68,    -1,    -1,    68,
      44,    -1,    70,    44,    71,    -1,    45,     3,    -1,    38,
       3,    -1,    -1,    71,    72,    -1,     6,     3,    44,    -1,
       9,     3,    44,    -1,    10,     3,    44,    -1,    19,    44,
      -1,    20,    44,    -1,    21,    44,    -1,    25,     3,    44,
      -1,    23,     3,    44,    -1,    24,     3,    44,    -1,    29,
      84,    44,    -1,    28,     3,    44,    -1,    58,     3,    44,
      -1,    59,     3,    44,    -1,    57,     3,    44,    -1,    31,
      22,    44,    -1,    30,    89,    44,    -1,    11,    85,    44,
      -1,    -1,     7,     3,    73,    86,    44,    -1,     8,     3,
       3,    88,    44,    -1,    -1,    37,    74,    93,    44,    -1,
      -1,    55,    75,    93,    44,    -1,    -1,    35,    76,    97,
      44,    -1,    -1,    12,    77,    97,    44,    -1,    -1,    13,
      78,   100,    44,    -1,    -1,    33,    79,    97,    44,    -1,
      -1,    32,    80,    97,    44,    -1,    -1,    34,    81,    97,
      44,    -1,    -1,    36,    82,    97,    44,    -1,    -1,    56,
      83,    97,    44,    -1,    60,    44,   111,    -1,    26,    92,
      -1,     1,    -1,    -1,    84,     3,    -1,    -1,    85,     3,
      -1,    -1,     3,    87,    -1,    -1,    22,    -1,    -1,    22,
      -1,    -1,     3,    90,    91,    -1,    -1,    46,     3,    47,
      -1,    -1,    92,    39,    44,    -1,    92,    39,    40,    -1,
      -1,    93,    42,    94,    96,    -1,    -1,    95,    96,    -1,
       3,    -1,    96,    43,     3,    -1,    -1,    98,   104,    -1,
      -1,    97,   103,    99,   104,    -1,    -1,   101,   104,    -1,
      -1,   100,   102,   104,    -1,    -1,    42,    -1,    42,    44,
      -1,    -1,     3,   105,   107,   109,    -1,    -1,   104,    43,
       3,   106,   107,   109,    -1,    -1,    46,   108,     3,    47,
      -1,    48,    -1,    50,    -1,    49,    -1,    52,    -1,    51,
      -1,    -1,    53,   110,    54,    -1,    -1,   110,     3,    -1,
      -1,    -1,   111,    22,     3,     3,   112,    44,    -1
};

/* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
static const unsigned char yyrline[] =
{
       0,    62,    62,    65,    66,    70,    70,    71,    71,    74,
      75,    78,    79,    83,    87,    88,    91,    92,    96,    97,
      98,    99,   100,   101,   102,   103,   104,   105,   106,   107,
     108,   109,   110,   111,   112,   113,   113,   114,   115,   115,
     116,   116,   117,   117,   118,   118,   119,   119,   120,   120,
     121,   121,   122,   122,   123,   123,   124,   124,   125,   126,
     127,   133,   134,   137,   138,   141,   142,   145,   146,   149,
     150,   154,   154,   157,   158,   161,   162,   163,   167,   167,
     168,   168,   172,   173,   177,   177,   178,   178,   182,   182,
     183,   183,   187,   188,   189,   193,   193,   194,   194,   197,
     198,   202,   203,   204,   205,   206,   209,   210,   213,   214,
     218,   219,   219
};
#endif

#if YYDEBUG || YYERROR_VERBOSE
/* YYTNME[SYMBOL-NUM] -- String name of the symbol SYMBOL-NUM.
   First, the terminals, then, starting at YYNTOKENS, nonterminals. */
static const char *const yytname[] =
{
  "$end", "error", "$undefined", "STRING", "SETUP_TIMESTAMP", 
  "SETUP_VERSION", "PACKAGEVERSION", "INSTALL", "SOURCE", "SDESC", 
  "LDESC", "CATEGORY", "DEPENDS", "REQUIRES", "APATH", "PPATH", 
  "INCLUDE_SETUP", "EXCLUDE_PACKAGE", "DOWNLOAD_URL", "T_PREV", "T_CURR", 
  "T_TEST", "MD5", "INSTALLEDSIZE", "MAINTAINER", "PRIORITY", "DESCTAG", 
  "DESCRIPTION", "FILESIZE", "ARCHITECTURE", "SOURCEPACKAGE", "MD5LINE", 
  "RECOMMENDS", "PREDEPENDS", "SUGGESTS", "CONFLICTS", "REPLACES", 
  "PROVIDES", "PACKAGENAME", "STRTOEOL", "PARAGRAPH", "EMAIL", "COMMA", 
  "OR", "NL", "AT", "OPENBRACE", "CLOSEBRACE", "EQUAL", "GT", "LT", 
  "GTEQUAL", "LTEQUAL", "OPENSQUARE", "CLOSESQUARE", "BINARYPACKAGE", 
  "BUILDDEPENDS", "STANDARDSVERSION", "FORMAT", "DIRECTORY", "FILES", 
  "$accept", "whole_file", "setup_headers", "header", "@1", "@2", 
  "packages", "packageseparator", "package", "packagename", "packagedata", 
  "singleitem", "@3", "@4", "@5", "@6", "@7", "@8", "@9", "@10", "@11", 
  "@12", "@13", "packagearchspec", "categories", "installmeta", 
  "installMD5", "sourceMD5", "source", "@14", "versioninfo", "mlinedesc", 
  "packagelist", "@15", "@16", "packageentry", "versionedpackagelist", 
  "@17", "@18", "versionedpackagelistsp", "@19", "@20", "listseparator", 
  "versionedpackageentry", "@21", "@22", "versioncriteria", "operator", 
  "architecture", "architecturelist", "SourceFilesList", "@23", 0
};
#endif

# ifdef YYPRINT
/* YYTOKNUM[YYLEX-NUM] -- Internal token number corresponding to
   token YYLEX-NUM.  */
static const unsigned short yytoknum[] =
{
       0,   256,   257,   258,   259,   260,   261,   262,   263,   264,
     265,   266,   267,   268,   269,   270,   271,   272,   273,   274,
     275,   276,   277,   278,   279,   280,   281,   282,   283,   284,
     285,   286,   287,   288,   289,   290,   291,   292,   293,   294,
     295,   296,   297,   298,   299,   300,   301,   302,   303,   304,
     305,   306,   307,   308,   309,   310,   311,   312,   313,   314,
     315
};
# endif

/* YYR1[YYN] -- Symbol number of symbol that rule YYN derives.  */
static const unsigned char yyr1[] =
{
       0,    61,    62,    63,    63,    65,    64,    66,    64,    67,
      67,    68,    68,    69,    70,    70,    71,    71,    72,    72,
      72,    72,    72,    72,    72,    72,    72,    72,    72,    72,
      72,    72,    72,    72,    72,    73,    72,    72,    74,    72,
      75,    72,    76,    72,    77,    72,    78,    72,    79,    72,
      80,    72,    81,    72,    82,    72,    83,    72,    72,    72,
      72,    84,    84,    85,    85,    86,    86,    87,    87,    88,
      88,    90,    89,    91,    91,    92,    92,    92,    94,    93,
      95,    93,    96,    96,    98,    97,    99,    97,   101,   100,
     102,   100,   103,   103,   103,   105,   104,   106,   104,   107,
     107,   108,   108,   108,   108,   108,   109,   109,   110,   110,
     111,   112,   111
};

/* YYR2[YYN] -- Number of symbols composing right hand side of rule YYN.  */
static const unsigned char yyr2[] =
{
       0,     2,     3,     0,     2,     0,     4,     0,     4,     0,
       3,     0,     2,     3,     2,     2,     0,     2,     3,     3,
       3,     2,     2,     2,     3,     3,     3,     3,     3,     3,
       3,     3,     3,     3,     3,     0,     5,     5,     0,     4,
       0,     4,     0,     4,     0,     4,     0,     4,     0,     4,
       0,     4,     0,     4,     0,     4,     0,     4,     3,     2,
       1,     0,     2,     0,     2,     0,     2,     0,     1,     0,
       1,     0,     3,     0,     3,     0,     3,     3,     0,     4,
       0,     2,     1,     3,     0,     2,     0,     4,     0,     2,
       0,     3,     0,     1,     2,     0,     4,     0,     6,     0,
       4,     1,     1,     1,     1,     1,     0,     3,     0,     2,
       0,     0,     6
};

/* YYDEFACT[STATE-NAME] -- Default rule to reduce with in state
   STATE-NUM when YYTABLE doesn't specify something else to do.  Zero
   means the default is an error.  */
static const unsigned char yydefact[] =
{
       3,     0,    11,     1,     0,     0,     4,     9,     5,     7,
      12,     2,     0,     0,     0,     0,    11,     0,     6,     8,
      15,    14,    10,    16,     0,    60,     0,     0,     0,     0,
       0,    63,    44,    46,     0,     0,     0,     0,     0,     0,
      75,     0,    61,     0,     0,    50,    48,    52,    42,    54,
      38,    40,    56,     0,     0,     0,     0,    17,     0,    35,
       0,     0,     0,     0,    84,    88,    21,    22,    23,     0,
       0,     0,    59,     0,     0,    71,     0,     0,    84,    84,
      84,    84,    84,    80,    80,    84,     0,     0,     0,   110,
      18,    65,    69,    19,    20,    64,    34,    92,     0,    90,
       0,    25,    26,    24,     0,    28,    62,    27,    73,    33,
      32,    92,    92,    92,    92,    92,     0,     0,     0,    92,
      31,    29,    30,    58,    67,     0,    70,     0,    93,    45,
      86,    95,    85,    47,     0,    89,    77,    76,     0,    72,
      51,    49,    53,    43,    55,    78,    39,    82,    81,    41,
      57,     0,    68,    66,    36,    37,    94,     0,    99,     0,
      91,     0,     0,     0,     0,    87,     0,   106,    97,    74,
      79,    83,   111,   101,   103,   102,   105,   104,     0,   108,
      96,    99,     0,     0,     0,   106,   112,   100,   109,   107,
      98
};

/* YYDEFGOTO[NTERM-NUM]. */
static const short yydefgoto[] =
{
      -1,     1,     2,     6,    12,    13,    11,     7,    16,    17,
      24,    57,    91,    83,    84,    81,    64,    65,    79,    78,
      80,    82,    85,    74,    63,   125,   153,   127,    76,   108,
     139,    72,   116,   162,   117,   148,    97,    98,   157,    99,
     100,   134,   130,   132,   158,   181,   167,   178,   180,   184,
     123,   182
};

/* YYPACT[STATE-NUM] -- Index in YYTABLE of the portion describing
   STATE-NUM.  */
#define YYPACT_NINF -96
static const short yypact[] =
{
     -96,     3,    84,   -96,     1,    37,   -96,    -3,   -96,   -96,
     -96,    26,     8,    17,    63,    66,   -96,    42,   -96,   -96,
     -96,   -96,    -3,   -96,     0,   -96,    87,    88,    89,    90,
      91,   -96,   -96,   -96,    51,    52,    53,    95,    96,    97,
     -96,    98,   -96,    99,    21,   -96,   -96,   -96,   -96,   -96,
     -96,   -96,   -96,   100,   101,   102,    62,   -96,    64,   -96,
     104,    65,    67,    19,   -96,   -96,   -96,   -96,   -96,    68,
      69,    70,    71,    72,    24,   -96,    73,    74,   -96,   -96,
     -96,   -96,   -96,   -96,   -96,   -96,    75,    76,    77,   -96,
     -96,   112,   103,   -96,   -96,   -96,   -96,    23,   119,    79,
     119,   -96,   -96,   -96,     2,   -96,   -96,   -96,    78,   -96,
     -96,    28,    31,    32,    35,    36,    39,   123,    40,    43,
     -96,   -96,   -96,   105,   106,    85,   -96,    86,    92,   -96,
     -96,   -96,    94,   -96,   119,    94,   -96,   -96,   128,   -96,
     -96,   -96,   -96,   -96,   -96,   -96,   -96,   -96,   107,   -96,
     -96,   129,   -96,   -96,   -96,   -96,   -96,   119,    93,   130,
      94,   108,   123,   131,   132,    94,   -34,   109,   -96,   -96,
     107,   -96,   -96,   -96,   -96,   -96,   -96,   -96,   135,   -96,
     -96,    93,   110,   111,    -1,   109,   -96,   -96,   -96,   -96,
     -96
};

/* YYPGOTO[NTERM-NUM].  */
static const yysigned_char yypgoto[] =
{
     -96,   -96,   -96,   -96,   -96,   -96,   -96,   124,   -96,   -96,
     -96,   -96,   -96,   -96,   -96,   -96,   -96,   -96,   -96,   -96,
     -96,   -96,   -96,   -96,   -96,   -96,   -96,   -96,   -96,   -96,
     -96,   -96,    57,   -96,   -96,   -20,   -31,   -96,   -96,   -96,
     -96,   -96,   -96,   -95,   -96,   -96,   -38,   -96,   -41,   -96,
     -96,   -96
};

/* YYTABLE[YYPACT[STATE-NUM]].  What to do in state STATE-NUM.  If
   positive, shift that token.  If negative, reduce the rule which
   number is the opposite.  If zero, do what YYDEFACT says.
   If YYTABLE_NINF, parse error.  */
#define YYTABLE_NINF -14
static const short yytable[] =
{
     -13,    25,   188,     3,     8,   135,    26,    27,    28,    29,
      30,    31,    32,    33,   173,   174,   175,   176,   177,    34,
      35,    36,    95,    37,    38,    39,    40,   106,    41,    42,
      43,    44,    45,    46,    47,    48,    49,    50,   -13,   160,
       9,    10,   136,    77,   -13,   -13,   137,   111,   112,   113,
     114,   115,    18,   189,   119,    51,    52,    53,    54,    55,
      56,    19,   165,    96,    14,   128,    20,   129,   107,    21,
     128,    15,   140,   128,   128,   141,   142,   128,   128,   143,
     144,   145,   145,   146,   149,   128,    23,   150,     4,     5,
      58,    59,    60,    61,    62,    66,    67,    68,    69,    70,
      71,    73,    75,    86,    87,    88,    89,    92,    90,    93,
     104,    94,   101,   102,   103,   124,   105,   109,   110,   120,
     121,   122,   131,   133,   138,   126,   147,   151,   152,   154,
     155,   161,   164,   168,   171,   172,   156,   159,   183,   166,
      22,   118,   170,   185,   190,     0,     0,     0,     0,     0,
     163,     0,     0,     0,   186,   169,     0,     0,   187,     0,
       0,     0,   179
};

static const short yycheck[] =
{
       0,     1,     3,     0,     3,   100,     6,     7,     8,     9,
      10,    11,    12,    13,    48,    49,    50,    51,    52,    19,
      20,    21,     3,    23,    24,    25,    26,     3,    28,    29,
      30,    31,    32,    33,    34,    35,    36,    37,    38,   134,
       3,    44,    40,    22,    44,    45,    44,    78,    79,    80,
      81,    82,    44,    54,    85,    55,    56,    57,    58,    59,
      60,    44,   157,    44,    38,    42,     3,    44,    44,     3,
      42,    45,    44,    42,    42,    44,    44,    42,    42,    44,
      44,    42,    42,    44,    44,    42,    44,    44,     4,     5,
       3,     3,     3,     3,     3,    44,    44,    44,     3,     3,
       3,     3,     3,     3,     3,     3,    44,     3,    44,    44,
      39,    44,    44,    44,    44,     3,    44,    44,    44,    44,
      44,    44,     3,    44,    46,    22,     3,    22,    22,    44,
      44,     3,     3,     3,     3,     3,    44,    43,     3,    46,
      16,    84,   162,   181,   185,    -1,    -1,    -1,    -1,    -1,
      43,    -1,    -1,    -1,    44,    47,    -1,    -1,    47,    -1,
      -1,    -1,    53
};

/* YYSTOS[STATE-NUM] -- The (internal number of the) accessing
   symbol of state STATE-NUM.  */
static const unsigned char yystos[] =
{
       0,    62,    63,     0,     4,     5,    64,    68,     3,     3,
      44,    67,    65,    66,    38,    45,    69,    70,    44,    44,
       3,     3,    68,    44,    71,     1,     6,     7,     8,     9,
      10,    11,    12,    13,    19,    20,    21,    23,    24,    25,
      26,    28,    29,    30,    31,    32,    33,    34,    35,    36,
      37,    55,    56,    57,    58,    59,    60,    72,     3,     3,
       3,     3,     3,    85,    77,    78,    44,    44,    44,     3,
       3,     3,    92,     3,    84,     3,    89,    22,    80,    79,
      81,    76,    82,    74,    75,    83,     3,     3,     3,    44,
      44,    73,     3,    44,    44,     3,    44,    97,    98,   100,
     101,    44,    44,    44,    39,    44,     3,    44,    90,    44,
      44,    97,    97,    97,    97,    97,    93,    95,    93,    97,
      44,    44,    44,   111,     3,    86,    22,    88,    42,    44,
     103,     3,   104,    44,   102,   104,    40,    44,    46,    91,
      44,    44,    44,    44,    44,    42,    44,     3,    96,    44,
      44,    22,    22,    87,    44,    44,    44,    99,   105,    43,
     104,     3,    94,    43,     3,   104,    46,   107,     3,    47,
      96,     3,     3,    48,    49,    50,    51,    52,   108,    53,
     109,   106,   112,     3,   110,   107,    44,    47,     3,    54,
     109
};

#if ! defined (YYSIZE_T) && defined (__SIZE_TYPE__)
# define YYSIZE_T __SIZE_TYPE__
#endif
#if ! defined (YYSIZE_T) && defined (size_t)
# define YYSIZE_T size_t
#endif
#if ! defined (YYSIZE_T)
# if defined (__STDC__) || defined (__cplusplus)
#  include <stddef.h> /* INFRINGES ON USER NAME SPACE */
#  define YYSIZE_T size_t
# endif
#endif
#if ! defined (YYSIZE_T)
# define YYSIZE_T unsigned int
#endif

#define yyerrok		(yyerrstatus = 0)
#define yyclearin	(yychar = YYEMPTY)
#define YYEMPTY		-2
#define YYEOF		0

#define YYACCEPT	goto yyacceptlab
#define YYABORT		goto yyabortlab
#define YYERROR		goto yyerrlab1

/* Like YYERROR except do call yyerror.  This remains here temporarily
   to ease the transition to the new meaning of YYERROR, for GCC.
   Once GCC version 2 has supplanted version 1, this can go.  */

#define YYFAIL		goto yyerrlab

#define YYRECOVERING()  (!!yyerrstatus)

#define YYBACKUP(Token, Value)					\
do								\
  if (yychar == YYEMPTY && yylen == 1)				\
    {								\
      yychar = (Token);						\
      yylval = (Value);						\
      yychar1 = YYTRANSLATE (yychar);				\
      YYPOPSTACK;						\
      goto yybackup;						\
    }								\
  else								\
    { 								\
      yyerror ("syntax error: cannot back up");			\
      YYERROR;							\
    }								\
while (0)

#define YYTERROR	1
#define YYERRCODE	256

/* YYLLOC_DEFAULT -- Compute the default location (before the actions
   are run).  */

#ifndef YYLLOC_DEFAULT
# define YYLLOC_DEFAULT(Current, Rhs, N)           \
  Current.first_line   = Rhs[1].first_line;      \
  Current.first_column = Rhs[1].first_column;    \
  Current.last_line    = Rhs[N].last_line;       \
  Current.last_column  = Rhs[N].last_column;
#endif

/* YYLEX -- calling `yylex' with the right arguments.  */

#define YYLEX	yylex ()

/* Enable debugging if requested.  */
#if YYDEBUG

# ifndef YYFPRINTF
#  include <stdio.h> /* INFRINGES ON USER NAME SPACE */
#  define YYFPRINTF fprintf
# endif

# define YYDPRINTF(Args)			\
do {						\
  if (yydebug)					\
    YYFPRINTF Args;				\
} while (0)
# define YYDSYMPRINT(Args)			\
do {						\
  if (yydebug)					\
    yysymprint Args;				\
} while (0)
/* Nonzero means print parse trace.  It is left uninitialized so that
   multiple parsers can coexist.  */
int yydebug;
#else /* !YYDEBUG */
# define YYDPRINTF(Args)
# define YYDSYMPRINT(Args)
#endif /* !YYDEBUG */

/* YYINITDEPTH -- initial size of the parser's stacks.  */
#ifndef	YYINITDEPTH
# define YYINITDEPTH 200
#endif

/* YYMAXDEPTH -- maximum size the stacks can grow to (effective only
   if the built-in stack extension method is used).

   Do not make this value too large; the results are undefined if
   SIZE_MAX < YYSTACK_BYTES (YYMAXDEPTH)
   evaluated with infinite-precision integer arithmetic.  */

#if YYMAXDEPTH == 0
# undef YYMAXDEPTH
#endif

#ifndef YYMAXDEPTH
# define YYMAXDEPTH 10000
#endif



#if YYERROR_VERBOSE

# ifndef yystrlen
#  if defined (__GLIBC__) && defined (_STRING_H)
#   define yystrlen strlen
#  else
/* Return the length of YYSTR.  */
static YYSIZE_T
#   if defined (__STDC__) || defined (__cplusplus)
yystrlen (const char *yystr)
#   else
yystrlen (yystr)
     const char *yystr;
#   endif
{
  register const char *yys = yystr;

  while (*yys++ != '\0')
    continue;

  return yys - yystr - 1;
}
#  endif
# endif

# ifndef yystpcpy
#  if defined (__GLIBC__) && defined (_STRING_H) && defined (_GNU_SOURCE)
#   define yystpcpy stpcpy
#  else
/* Copy YYSRC to YYDEST, returning the address of the terminating '\0' in
   YYDEST.  */
static char *
#   if defined (__STDC__) || defined (__cplusplus)
yystpcpy (char *yydest, const char *yysrc)
#   else
yystpcpy (yydest, yysrc)
     char *yydest;
     const char *yysrc;
#   endif
{
  register char *yyd = yydest;
  register const char *yys = yysrc;

  while ((*yyd++ = *yys++) != '\0')
    continue;

  return yyd - 1;
}
#  endif
# endif

#endif /* !YYERROR_VERBOSE */



#if YYDEBUG
/*-----------------------------.
| Print this symbol on YYOUT.  |
`-----------------------------*/

static void
#if defined (__STDC__) || defined (__cplusplus)
yysymprint (FILE* yyout, int yytype, YYSTYPE yyvalue)
#else
yysymprint (yyout, yytype, yyvalue)
    FILE* yyout;
    int yytype;
    YYSTYPE yyvalue;
#endif
{
  /* Pacify ``unused variable'' warnings.  */
  (void) yyvalue;

  if (yytype < YYNTOKENS)
    {
      YYFPRINTF (yyout, "token %s (", yytname[yytype]);
# ifdef YYPRINT
      YYPRINT (yyout, yytoknum[yytype], yyvalue);
# endif
    }
  else
    YYFPRINTF (yyout, "nterm %s (", yytname[yytype]);

  switch (yytype)
    {
      default:
        break;
    }
  YYFPRINTF (yyout, ")");
}
#endif /* YYDEBUG. */


/*-----------------------------------------------.
| Release the memory associated to this symbol.  |
`-----------------------------------------------*/

static void
#if defined (__STDC__) || defined (__cplusplus)
yydestruct (int yytype, YYSTYPE yyvalue)
#else
yydestruct (yytype, yyvalue)
    int yytype;
    YYSTYPE yyvalue;
#endif
{
  /* Pacify ``unused variable'' warnings.  */
  (void) yyvalue;

  switch (yytype)
    {
      default:
        break;
    }
}



/* The user can define YYPARSE_PARAM as the name of an argument to be passed
   into yyparse.  The argument should have type void *.
   It should actually point to an object.
   Grammar actions can access the variable by casting it
   to the proper pointer type.  */

#ifdef YYPARSE_PARAM
# if defined (__STDC__) || defined (__cplusplus)
#  define YYPARSE_PARAM_ARG void *YYPARSE_PARAM
#  define YYPARSE_PARAM_DECL
# else
#  define YYPARSE_PARAM_ARG YYPARSE_PARAM
#  define YYPARSE_PARAM_DECL void *YYPARSE_PARAM;
# endif
#else /* !YYPARSE_PARAM */
# define YYPARSE_PARAM_ARG
# define YYPARSE_PARAM_DECL
#endif /* !YYPARSE_PARAM */

/* Prevent warning if -Wstrict-prototypes.  */
#ifdef __GNUC__
# ifdef YYPARSE_PARAM
int yyparse (void *);
# else
int yyparse (void);
# endif
#endif


/* The lookahead symbol.  */
int yychar;

/* The semantic value of the lookahead symbol.  */
YYSTYPE yylval;

/* Number of parse errors so far.  */
int yynerrs;


int
yyparse (YYPARSE_PARAM_ARG)
     YYPARSE_PARAM_DECL
{
  
  register int yystate;
  register int yyn;
  int yyresult;
  /* Number of tokens to shift before error messages enabled.  */
  int yyerrstatus;
  /* Lookahead token as an internal (translated) token number.  */
  int yychar1 = 0;

  /* Three stacks and their tools:
     `yyss': related to states,
     `yyvs': related to semantic values,
     `yyls': related to locations.

     Refer to the stacks thru separate pointers, to allow yyoverflow
     to reallocate them elsewhere.  */

  /* The state stack.  */
  short	yyssa[YYINITDEPTH];
  short *yyss = yyssa;
  register short *yyssp;

  /* The semantic value stack.  */
  YYSTYPE yyvsa[YYINITDEPTH];
  YYSTYPE *yyvs = yyvsa;
  register YYSTYPE *yyvsp;



#define YYPOPSTACK   (yyvsp--, yyssp--)

  YYSIZE_T yystacksize = YYINITDEPTH;

  /* The variables used to return semantic value and location from the
     action routines.  */
  YYSTYPE yyval;


  /* When reducing, the number of symbols on the RHS of the reduced
     rule.  */
  int yylen;

  YYDPRINTF ((stderr, "Starting parse\n"));

  yystate = 0;
  yyerrstatus = 0;
  yynerrs = 0;
  yychar = YYEMPTY;		/* Cause a token to be read.  */

  /* Initialize stack pointers.
     Waste one element of value and location stack
     so that they stay on the same level as the state stack.
     The wasted elements are never initialized.  */

  yyssp = yyss;
  yyvsp = yyvs;

  goto yysetstate;

/*------------------------------------------------------------.
| yynewstate -- Push a new state, which is found in yystate.  |
`------------------------------------------------------------*/
 yynewstate:
  /* In all cases, when you get here, the value and location stacks
     have just been pushed. so pushing a state here evens the stacks.
     */
  yyssp++;

 yysetstate:
  *yyssp = yystate;

  if (yyssp >= yyss + yystacksize - 1)
    {
      /* Get the current used size of the three stacks, in elements.  */
      YYSIZE_T yysize = yyssp - yyss + 1;

#ifdef yyoverflow
      {
	/* Give user a chance to reallocate the stack. Use copies of
	   these so that the &'s don't force the real ones into
	   memory.  */
	YYSTYPE *yyvs1 = yyvs;
	short *yyss1 = yyss;


	/* Each stack pointer address is followed by the size of the
	   data in use in that stack, in bytes.  This used to be a
	   conditional around just the two extra args, but that might
	   be undefined if yyoverflow is a macro.  */
	yyoverflow ("parser stack overflow",
		    &yyss1, yysize * sizeof (*yyssp),
		    &yyvs1, yysize * sizeof (*yyvsp),

		    &yystacksize);

	yyss = yyss1;
	yyvs = yyvs1;
      }
#else /* no yyoverflow */
# ifndef YYSTACK_RELOCATE
      goto yyoverflowlab;
# else
      /* Extend the stack our own way.  */
      if (yystacksize >= YYMAXDEPTH)
	goto yyoverflowlab;
      yystacksize *= 2;
      if (yystacksize > YYMAXDEPTH)
	yystacksize = YYMAXDEPTH;

      {
	short *yyss1 = yyss;
	union yyalloc *yyptr =
	  (union yyalloc *) YYSTACK_ALLOC (YYSTACK_BYTES (yystacksize));
	if (! yyptr)
	  goto yyoverflowlab;
	YYSTACK_RELOCATE (yyss);
	YYSTACK_RELOCATE (yyvs);

#  undef YYSTACK_RELOCATE
	if (yyss1 != yyssa)
	  YYSTACK_FREE (yyss1);
      }
# endif
#endif /* no yyoverflow */

      yyssp = yyss + yysize - 1;
      yyvsp = yyvs + yysize - 1;


      YYDPRINTF ((stderr, "Stack size increased to %lu\n",
		  (unsigned long int) yystacksize));

      if (yyssp >= yyss + yystacksize - 1)
	YYABORT;
    }

  YYDPRINTF ((stderr, "Entering state %d\n", yystate));

  goto yybackup;

/*-----------.
| yybackup.  |
`-----------*/
yybackup:

/* Do appropriate processing given the current state.  */
/* Read a lookahead token if we need one and don't already have one.  */
/* yyresume: */

  /* First try to decide what to do without reference to lookahead token.  */

  yyn = yypact[yystate];
  if (yyn == YYPACT_NINF)
    goto yydefault;

  /* Not known => get a lookahead token if don't already have one.  */

  /* yychar is either YYEMPTY or YYEOF
     or a valid token in external form.  */

  if (yychar == YYEMPTY)
    {
      YYDPRINTF ((stderr, "Reading a token: "));
      yychar = YYLEX;
    }

  /* Convert token to internal form (in yychar1) for indexing tables with.  */

  if (yychar <= 0)		/* This means end of input.  */
    {
      yychar1 = 0;
      yychar = YYEOF;		/* Don't call YYLEX any more.  */

      YYDPRINTF ((stderr, "Now at end of input.\n"));
    }
  else
    {
      yychar1 = YYTRANSLATE (yychar);

      /* We have to keep this `#if YYDEBUG', since we use variables
	 which are defined only if `YYDEBUG' is set.  */
      YYDPRINTF ((stderr, "Next token is "));
      YYDSYMPRINT ((stderr, yychar1, yylval));
      YYDPRINTF ((stderr, "\n"));
    }

  /* If the proper action on seeing token YYCHAR1 is to reduce or to
     detect an error, take that action.  */
  yyn += yychar1;
  if (yyn < 0 || YYLAST < yyn || yycheck[yyn] != yychar1)
    goto yydefault;
  yyn = yytable[yyn];
  if (yyn <= 0)
    {
      if (yyn == 0 || yyn == YYTABLE_NINF)
	goto yyerrlab;
      yyn = -yyn;
      goto yyreduce;
    }

  if (yyn == YYFINAL)
    YYACCEPT;

  /* Shift the lookahead token.  */
  YYDPRINTF ((stderr, "Shifting token %d (%s), ",
	      yychar, yytname[yychar1]));

  /* Discard the token being shifted unless it is eof.  */
  if (yychar != YYEOF)
    yychar = YYEMPTY;

  *++yyvsp = yylval;


  /* Count tokens shifted since error; after three, turn off error
     status.  */
  if (yyerrstatus)
    yyerrstatus--;

  yystate = yyn;
  goto yynewstate;


/*-----------------------------------------------------------.
| yydefault -- do the default action for the current state.  |
`-----------------------------------------------------------*/
yydefault:
  yyn = yydefact[yystate];
  if (yyn == 0)
    goto yyerrlab;
  goto yyreduce;


/*-----------------------------.
| yyreduce -- Do a reduction.  |
`-----------------------------*/
yyreduce:
  /* yyn is the number of a rule to reduce with.  */
  yylen = yyr2[yyn];

  /* If YYLEN is nonzero, implement the default value of the action:
     `$$ = $1'.

     Otherwise, the following line sets YYVAL to garbage.
     This behavior is undocumented and Bison
     users should not rely upon it.  Assigning to YYVAL
     unconditionally makes the parser a bit smaller, and it avoids a
     GCC warning that YYVAL may be used uninitialized.  */
  yyval = yyvsp[1-yylen];



#if YYDEBUG
  /* We have to keep this `#if YYDEBUG', since we use variables which
     are defined only if `YYDEBUG' is set.  */
  if (yydebug)
    {
      int yyi;

      YYFPRINTF (stderr, "Reducing via rule %d (line %d), ",
		 yyn - 1, yyrline[yyn]);

      /* Print the symbols being reduced, and their result.  */
      for (yyi = yyprhs[yyn]; yyrhs[yyi] >= 0; yyi++)
	YYFPRINTF (stderr, "%s ", yytname[yyrhs[yyi]]);
      YYFPRINTF (stderr, " -> %s\n", yytname[yyr1[yyn]]);
    }
#endif
  switch (yyn)
    {
        case 5:
#line 70 "/home/RobertC/src/cygwin/setup/iniparse.y"
    { iniBuilder->buildTimestamp (yyvsp[0]); }
    break;

  case 7:
#line 71 "/home/RobertC/src/cygwin/setup/iniparse.y"
    { iniBuilder->buildVersion (yyvsp[0]); }
    break;

  case 14:
#line 87 "/home/RobertC/src/cygwin/setup/iniparse.y"
    { iniBuilder->buildPackage (yyvsp[0]); }
    break;

  case 15:
#line 88 "/home/RobertC/src/cygwin/setup/iniparse.y"
    { iniBuilder->buildPackage (yyvsp[0]); }
    break;

  case 18:
#line 96 "/home/RobertC/src/cygwin/setup/iniparse.y"
    { iniBuilder->buildPackageVersion (yyvsp[-1]); }
    break;

  case 19:
#line 97 "/home/RobertC/src/cygwin/setup/iniparse.y"
    { iniBuilder->buildPackageSDesc(yyvsp[-1]); }
    break;

  case 20:
#line 98 "/home/RobertC/src/cygwin/setup/iniparse.y"
    { iniBuilder->buildPackageLDesc(yyvsp[-1]); }
    break;

  case 21:
#line 99 "/home/RobertC/src/cygwin/setup/iniparse.y"
    { iniBuilder->buildPackageTrust (TRUST_PREV); }
    break;

  case 22:
#line 100 "/home/RobertC/src/cygwin/setup/iniparse.y"
    { iniBuilder->buildPackageTrust (TRUST_CURR); }
    break;

  case 23:
#line 101 "/home/RobertC/src/cygwin/setup/iniparse.y"
    { iniBuilder->buildPackageTrust (TRUST_TEST); }
    break;

  case 24:
#line 102 "/home/RobertC/src/cygwin/setup/iniparse.y"
    { iniBuilder->buildPriority (yyvsp[-1]); }
    break;

  case 25:
#line 103 "/home/RobertC/src/cygwin/setup/iniparse.y"
    { iniBuilder->buildInstalledSize (yyvsp[-1]); }
    break;

  case 26:
#line 104 "/home/RobertC/src/cygwin/setup/iniparse.y"
    { iniBuilder->buildMaintainer (yyvsp[-1]); }
    break;

  case 27:
#line 105 "/home/RobertC/src/cygwin/setup/iniparse.y"
    { iniBuilder->buildArchitecture (yyvsp[-1]); }
    break;

  case 28:
#line 106 "/home/RobertC/src/cygwin/setup/iniparse.y"
    { iniBuilder->buildInstallSize(yyvsp[-1]); }
    break;

  case 29:
#line 107 "/home/RobertC/src/cygwin/setup/iniparse.y"
    { /* TODO */ }
    break;

  case 30:
#line 108 "/home/RobertC/src/cygwin/setup/iniparse.y"
    { /* TODO */ }
    break;

  case 31:
#line 109 "/home/RobertC/src/cygwin/setup/iniparse.y"
    { /* TODO */ }
    break;

  case 32:
#line 110 "/home/RobertC/src/cygwin/setup/iniparse.y"
    { iniBuilder->buildInstallMD5 ((unsigned char *)yyvsp[-1]); }
    break;

  case 35:
#line 113 "/home/RobertC/src/cygwin/setup/iniparse.y"
    { iniBuilder->buildPackageInstall (yyvsp[0]); }
    break;

  case 37:
#line 114 "/home/RobertC/src/cygwin/setup/iniparse.y"
    {iniBuilder->buildPackageSource (yyvsp[-3], yyvsp[-2]);}
    break;

  case 38:
#line 115 "/home/RobertC/src/cygwin/setup/iniparse.y"
    { iniBuilder->buildBeginProvides(); }
    break;

  case 40:
#line 116 "/home/RobertC/src/cygwin/setup/iniparse.y"
    { iniBuilder->buildBeginBinary (); }
    break;

  case 42:
#line 117 "/home/RobertC/src/cygwin/setup/iniparse.y"
    { iniBuilder->buildBeginConflicts(); }
    break;

  case 44:
#line 118 "/home/RobertC/src/cygwin/setup/iniparse.y"
    { iniBuilder->buildBeginDepends(); }
    break;

  case 46:
#line 119 "/home/RobertC/src/cygwin/setup/iniparse.y"
    { iniBuilder->buildBeginDepends(); }
    break;

  case 48:
#line 120 "/home/RobertC/src/cygwin/setup/iniparse.y"
    { iniBuilder->buildBeginPreDepends(); }
    break;

  case 50:
#line 121 "/home/RobertC/src/cygwin/setup/iniparse.y"
    { iniBuilder->buildBeginRecommends(); }
    break;

  case 52:
#line 122 "/home/RobertC/src/cygwin/setup/iniparse.y"
    { iniBuilder->buildBeginSuggests(); }
    break;

  case 54:
#line 123 "/home/RobertC/src/cygwin/setup/iniparse.y"
    { iniBuilder->buildBeginReplaces(); }
    break;

  case 56:
#line 124 "/home/RobertC/src/cygwin/setup/iniparse.y"
    { iniBuilder->buildBeginBuildDepends(); }
    break;

  case 60:
#line 127 "/home/RobertC/src/cygwin/setup/iniparse.y"
    { yyerror (String("unrecognized line ") 
					  + yylineno 
					  + " (do you have the latest setup?)");
				}
    break;

  case 62:
#line 134 "/home/RobertC/src/cygwin/setup/iniparse.y"
    { iniBuilder->buildArchitecture (yyvsp[0]); }
    break;

  case 64:
#line 138 "/home/RobertC/src/cygwin/setup/iniparse.y"
    { iniBuilder->buildPackageCategory (yyvsp[0]); }
    break;

  case 66:
#line 142 "/home/RobertC/src/cygwin/setup/iniparse.y"
    { iniBuilder->buildInstallSize(yyvsp[-1]); }
    break;

  case 68:
#line 146 "/home/RobertC/src/cygwin/setup/iniparse.y"
    { iniBuilder->buildInstallMD5 ((unsigned char *)yyvsp[0]);}
    break;

  case 70:
#line 150 "/home/RobertC/src/cygwin/setup/iniparse.y"
    { iniBuilder->buildSourceMD5 ((unsigned char *)yyvsp[0]); }
    break;

  case 71:
#line 154 "/home/RobertC/src/cygwin/setup/iniparse.y"
    { iniBuilder->buildSourceName (yyvsp[0]); }
    break;

  case 74:
#line 158 "/home/RobertC/src/cygwin/setup/iniparse.y"
    { iniBuilder->buildSourceNameVersion (yyvsp[-1]); }
    break;

  case 76:
#line 162 "/home/RobertC/src/cygwin/setup/iniparse.y"
    { iniBuilder->buildDescription (yyvsp[-1]); }
    break;

  case 77:
#line 163 "/home/RobertC/src/cygwin/setup/iniparse.y"
    { iniBuilder->buildDescription (yyvsp[-1]); }
    break;

  case 78:
#line 167 "/home/RobertC/src/cygwin/setup/iniparse.y"
    { iniBuilder->buildPackageListAndNode(); }
    break;

  case 80:
#line 168 "/home/RobertC/src/cygwin/setup/iniparse.y"
    { iniBuilder->buildPackageListAndNode(); }
    break;

  case 82:
#line 172 "/home/RobertC/src/cygwin/setup/iniparse.y"
    { iniBuilder->buildPackageListOrNode(yyvsp[0]); }
    break;

  case 83:
#line 173 "/home/RobertC/src/cygwin/setup/iniparse.y"
    { iniBuilder->buildPackageListOrNode(yyvsp[0]); }
    break;

  case 84:
#line 177 "/home/RobertC/src/cygwin/setup/iniparse.y"
    { iniBuilder->buildPackageListAndNode(); }
    break;

  case 86:
#line 178 "/home/RobertC/src/cygwin/setup/iniparse.y"
    { iniBuilder->buildPackageListAndNode(); }
    break;

  case 88:
#line 182 "/home/RobertC/src/cygwin/setup/iniparse.y"
    { iniBuilder->buildPackageListAndNode(); }
    break;

  case 90:
#line 183 "/home/RobertC/src/cygwin/setup/iniparse.y"
    { iniBuilder->buildPackageListAndNode(); }
    break;

  case 95:
#line 193 "/home/RobertC/src/cygwin/setup/iniparse.y"
    { iniBuilder->buildPackageListOrNode(yyvsp[0]); }
    break;

  case 97:
#line 194 "/home/RobertC/src/cygwin/setup/iniparse.y"
    { iniBuilder->buildPackageListOrNode(yyvsp[0]); }
    break;

  case 100:
#line 198 "/home/RobertC/src/cygwin/setup/iniparse.y"
    { iniBuilder->buildPackageListOperatorVersion (yyvsp[-1]); }
    break;

  case 101:
#line 202 "/home/RobertC/src/cygwin/setup/iniparse.y"
    { iniBuilder->buildPackageListOperator (PackageSpecification::Equals); }
    break;

  case 102:
#line 203 "/home/RobertC/src/cygwin/setup/iniparse.y"
    { iniBuilder->buildPackageListOperator (PackageSpecification::LessThan); }
    break;

  case 103:
#line 204 "/home/RobertC/src/cygwin/setup/iniparse.y"
    { iniBuilder->buildPackageListOperator (PackageSpecification::MoreThan); }
    break;

  case 104:
#line 205 "/home/RobertC/src/cygwin/setup/iniparse.y"
    { iniBuilder->buildPackageListOperator (PackageSpecification::LessThanEquals); }
    break;

  case 105:
#line 206 "/home/RobertC/src/cygwin/setup/iniparse.y"
    { iniBuilder->buildPackageListOperator (PackageSpecification::MoreThanEquals); }
    break;

  case 111:
#line 219 "/home/RobertC/src/cygwin/setup/iniparse.y"
    { iniBuilder->buildSourceFile ((unsigned char *)yyvsp[-2], yyvsp[-1], yyvsp[0]);  }
    break;


    }

/* Line 1016 of /usr/share/bison/yacc.c.  */
#line 1554 "iniparse.cc"

  yyvsp -= yylen;
  yyssp -= yylen;


#if YYDEBUG
  if (yydebug)
    {
      short *yyssp1 = yyss - 1;
      YYFPRINTF (stderr, "state stack now");
      while (yyssp1 != yyssp)
	YYFPRINTF (stderr, " %d", *++yyssp1);
      YYFPRINTF (stderr, "\n");
    }
#endif

  *++yyvsp = yyval;


  /* Now `shift' the result of the reduction.  Determine what state
     that goes to, based on the state we popped back to and the rule
     number reduced by.  */

  yyn = yyr1[yyn];

  yystate = yypgoto[yyn - YYNTOKENS] + *yyssp;
  if (0 <= yystate && yystate <= YYLAST && yycheck[yystate] == *yyssp)
    yystate = yytable[yystate];
  else
    yystate = yydefgoto[yyn - YYNTOKENS];

  goto yynewstate;


/*------------------------------------.
| yyerrlab -- here on detecting error |
`------------------------------------*/
yyerrlab:
  /* If not already recovering from an error, report this error.  */
  if (!yyerrstatus)
    {
      ++yynerrs;
#if YYERROR_VERBOSE
      yyn = yypact[yystate];

      if (YYPACT_NINF < yyn && yyn < YYLAST)
	{
	  YYSIZE_T yysize = 0;
	  int yytype = YYTRANSLATE (yychar);
	  char *yymsg;
	  int yyx, yycount;

	  yycount = 0;
	  /* Start YYX at -YYN if negative to avoid negative indexes in
	     YYCHECK.  */
	  for (yyx = yyn < 0 ? -yyn : 0;
	       yyx < (int) (sizeof (yytname) / sizeof (char *)); yyx++)
	    if (yycheck[yyx + yyn] == yyx && yyx != YYTERROR)
	      yysize += yystrlen (yytname[yyx]) + 15, yycount++;
	  yysize += yystrlen ("parse error, unexpected ") + 1;
	  yysize += yystrlen (yytname[yytype]);
	  yymsg = (char *) YYSTACK_ALLOC (yysize);
	  if (yymsg != 0)
	    {
	      char *yyp = yystpcpy (yymsg, "parse error, unexpected ");
	      yyp = yystpcpy (yyp, yytname[yytype]);

	      if (yycount < 5)
		{
		  yycount = 0;
		  for (yyx = yyn < 0 ? -yyn : 0;
		       yyx < (int) (sizeof (yytname) / sizeof (char *));
		       yyx++)
		    if (yycheck[yyx + yyn] == yyx && yyx != YYTERROR)
		      {
			const char *yyq = ! yycount ? ", expecting " : " or ";
			yyp = yystpcpy (yyp, yyq);
			yyp = yystpcpy (yyp, yytname[yyx]);
			yycount++;
		      }
		}
	      yyerror (yymsg);
	      YYSTACK_FREE (yymsg);
	    }
	  else
	    yyerror ("parse error; also virtual memory exhausted");
	}
      else
#endif /* YYERROR_VERBOSE */
	yyerror ("parse error");
    }
  goto yyerrlab1;


/*----------------------------------------------------.
| yyerrlab1 -- error raised explicitly by an action.  |
`----------------------------------------------------*/
yyerrlab1:
  if (yyerrstatus == 3)
    {
      /* If just tried and failed to reuse lookahead token after an
	 error, discard it.  */

      /* Return failure if at end of input.  */
      if (yychar == YYEOF)
        {
	  /* Pop the error token.  */
          YYPOPSTACK;
	  /* Pop the rest of the stack.  */
	  while (yyssp > yyss)
	    {
	      YYDPRINTF ((stderr, "Error: popping "));
	      YYDSYMPRINT ((stderr,
			    yystos[*yyssp],
			    *yyvsp));
	      YYDPRINTF ((stderr, "\n"));
	      yydestruct (yystos[*yyssp], *yyvsp);
	      YYPOPSTACK;
	    }
	  YYABORT;
        }

      YYDPRINTF ((stderr, "Discarding token %d (%s).\n",
		  yychar, yytname[yychar1]));
      yydestruct (yychar1, yylval);
      yychar = YYEMPTY;
    }

  /* Else will try to reuse lookahead token after shifting the error
     token.  */

  yyerrstatus = 3;	/* Each real token shifted decrements this.  */

  for (;;)
    {
      yyn = yypact[yystate];
      if (yyn != YYPACT_NINF)
	{
	  yyn += YYTERROR;
	  if (0 <= yyn && yyn <= YYLAST && yycheck[yyn] == YYTERROR)
	    {
	      yyn = yytable[yyn];
	      if (0 < yyn)
		break;
	    }
	}

      /* Pop the current state because it cannot handle the error token.  */
      if (yyssp == yyss)
	YYABORT;

      YYDPRINTF ((stderr, "Error: popping "));
      YYDSYMPRINT ((stderr,
		    yystos[*yyssp], *yyvsp));
      YYDPRINTF ((stderr, "\n"));

      yydestruct (yystos[yystate], *yyvsp);
      yyvsp--;
      yystate = *--yyssp;


#if YYDEBUG
      if (yydebug)
	{
	  short *yyssp1 = yyss - 1;
	  YYFPRINTF (stderr, "Error: state stack now");
	  while (yyssp1 != yyssp)
	    YYFPRINTF (stderr, " %d", *++yyssp1);
	  YYFPRINTF (stderr, "\n");
	}
#endif
    }

  if (yyn == YYFINAL)
    YYACCEPT;

  YYDPRINTF ((stderr, "Shifting error token, "));

  *++yyvsp = yylval;


  yystate = yyn;
  goto yynewstate;


/*-------------------------------------.
| yyacceptlab -- YYACCEPT comes here.  |
`-------------------------------------*/
yyacceptlab:
  yyresult = 0;
  goto yyreturn;

/*-----------------------------------.
| yyabortlab -- YYABORT comes here.  |
`-----------------------------------*/
yyabortlab:
  yyresult = 1;
  goto yyreturn;

#ifndef yyoverflow
/*----------------------------------------------.
| yyoverflowlab -- parser overflow comes here.  |
`----------------------------------------------*/
yyoverflowlab:
  yyerror ("parser stack overflow");
  yyresult = 2;
  /* Fall through.  */
#endif

yyreturn:
#ifndef yyoverflow
  if (yyss != yyssa)
    YYSTACK_FREE (yyss);
#endif
  return yyresult;
}


#line 222 "/home/RobertC/src/cygwin/setup/iniparse.y"


